@@ -1,5 +1,5 @@
 # These functions are
-# Copyright (C) 1998-2018 T.W. Yee, University of Auckland.
+# Copyright (C) 1998-2019 T.W. Yee, University of Auckland.
 # All rights reserved.
 
 
@@ -13,16 +13,20 @@
 
 
 
+
  binomialff <-
-  function(link = "logit",
-           dispersion = 1,
-           multiple.responses = FALSE, onedpar = !multiple.responses,
+  function(link = "logitlink",
+           multiple.responses = FALSE,
            parallel = FALSE,  # apply.parint = FALSE,
            zero = NULL,
            bred = FALSE,
            earg.link = FALSE) {
 
 
+  dispersion = 1
+  onedpar = !multiple.responses
+
+
  if (!is.logical(bred) || length(bred) > 1)
    stop("argument 'bred' must be a single logical")
 
@@ -59,7 +63,7 @@
     if (!length(size <- extra$size))
       size <- 1
     if (varfun) {
-      size * mu * (1 - mu)
+      mu * (1 - mu) / size
     } else {
       (1 + mu * (exp(1i * x) - 1))^size
     }
@@ -84,17 +88,19 @@
          charfun = TRUE,
          expected = TRUE,
          hadof = TRUE,
+         multiple.responses = .multiple.responses ,
          parameters.names = c("prob"),  # new.name
          zero = .zero )
   }, list( .zero = zero,
-           .bred = bred ))),
+           .bred = bred,
+           .multiple.responses = multiple.responses ))),
 
   initialize = eval(substitute(expression({
     assign("CQO.FastAlgorithm",
-           ( .link == "logit" || .link == "cloglog"),
+           ( .link == "logitlink" || .link == "clogloglink"),
            envir = VGAMenv)
-    assign("modelno", if ( .link == "logit") 1 else
-                      if ( .link == "cloglog") 4 else NULL,
+    assign("modelno", if ( .link == "logitlink") 1 else
+                      if ( .link == "clogloglink") 4 else NULL,
            envir = VGAMenv)
 
 
@@ -244,12 +250,14 @@
       }
     }
 
-    misc$multiple.responses <- .multiple.responses
+
+
+    if (! ( .multiple.responses ))
+      extra$size <- nvec  # For @charfun, and therefore "stdres"
+
     misc$dispersion <- dpar
     misc$default.dispersion <- 1
     misc$estimated.dispersion <- .estimated.dispersion
-    misc$bred <- .bred
-    misc$expected <- TRUE
 
     misc$link <- rep_len( .link , M)
     names(misc$link) <- if (M > 1) dn2 else new.name  # Was old.name=="mu"
@@ -308,8 +316,7 @@
     okay1 <- all(is.finite(mymu)) && all(0 < mymu & mymu < 1)
     okay1
   }, list( .link = link, .earg = earg, .bred = bred))),
-  vfamily = c("binomialff", "VGAMcategorical"),
-
+  vfamily = c("binomialff", "VGAMglm"),  # "VGAMcategorical",
 
 
 
@@ -412,9 +419,9 @@
     }
 
 
-    answer <- if ( .link == "logit") {
+    answer <- if ( .link == "logitlink") {
       c(w) * (yBRED - mu)
-    } else if ( .link == "cloglog") {
+    } else if ( .link == "clogloglink") {
       mu.use <- mu
       smallno <- 100 * .Machine$double.eps
       mu.use[mu.use <       smallno] <-       smallno
@@ -431,9 +438,9 @@
   weight = eval(substitute(expression({
     tmp100 <- mu * (1.0 - mu)
 
-    ned2ldprob2 <- if ( .link == "logit") {
+    ned2ldprob2 <- if ( .link == "logitlink") {
       cbind(c(w) * tmp100)
-    } else if ( .link == "cloglog") {
+    } else if ( .link == "clogloglink") {
       cbind(c(w) * (1.0 - mu.use) * (log1p(-mu.use))^2 / mu.use)
     } else {
       cbind(c(w) * dtheta.deta(mu, link = .link ,
@@ -484,7 +491,9 @@
 
 
 
- gammaff <- function(link = "nreciprocal", dispersion = 0) {
+
+
+ gammaff <- function(link = "negreciprocal", dispersion = 0) {
   estimated.dispersion <- dispersion == 0
 
 
@@ -610,6 +619,8 @@
 
 
 
+
+
  inverse.gaussianff <- function(link = "natural.ig",
                                 dispersion = 0) {
   estimated.dispersion <- dispersion == 0
@@ -801,7 +812,7 @@ rinv.gaussian <- function(n, mu, lambda) {
 
 
 
- inv.gaussianff <- function(lmu = "loge", llambda = "loge",
+ inv.gaussianff <- function(lmu = "loglink", llambda = "loglink",
                             imethod = 1,  ilambda = NULL,
                             parallel = FALSE,
                             ishrinkage = 0.99,
@@ -1022,8 +1033,7 @@ rinv.gaussian <- function(n, mu, lambda) {
 
 
 
- poissonff <- function(link = "loge",
-                       dispersion = 1, onedpar = FALSE,
+ poissonff <- function(link = "loglink",
                        imu = NULL, imethod = 1,
                        parallel = FALSE, zero = NULL,
                        bred = FALSE,
@@ -1033,6 +1043,10 @@ rinv.gaussian <- function(n, mu, lambda) {
 
 
 
+  dispersion = 1
+  onedpar = FALSE
+
+
   type.fitted <- match.arg(type.fitted,
                            c("mean", "quantiles"))[1]
 
@@ -1139,7 +1153,7 @@ rinv.gaussian <- function(n, mu, lambda) {
 
     M <- ncoly <- ncol(y)
 
-    assign("CQO.FastAlgorithm", ( .link == "loge"), envir = VGAMenv)
+    assign("CQO.FastAlgorithm", ( .link == "loglink"), envir = VGAMenv)
 
 
 
@@ -1279,7 +1293,7 @@ rinv.gaussian <- function(n, mu, lambda) {
       }
     }
   }, list( .link = link, .earg = earg ))),
-  vfamily = "poissonff",
+  vfamily = c("poissonff", "VGAMglm"),  # For "stdres"
   validparams = eval(substitute(function(eta, y, extra = NULL) {
     mupo <- eta2theta(eta, link = .link , earg = .earg )
     okay1 <- all(is.finite(mupo)) && all(0 < mupo)
@@ -1340,7 +1354,7 @@ rinv.gaussian <- function(n, mu, lambda) {
     }
 
 
-    answer <- if ( .link == "loge" && (any(mupo < .Machine$double.eps))) {
+    answer <- if ( .link == "loglink" && (any(mupo < .Machine$double.eps))) {
       c(w) * (yBRED - mupo)
     } else {
       lambda <- mupo
@@ -1354,7 +1368,7 @@ rinv.gaussian <- function(n, mu, lambda) {
   }), list( .link = link, .earg = earg, .bred = bred))),
 
   weight = eval(substitute(expression({
-    if ( .link == "loge" && (any(mupo < .Machine$double.eps))) {
+    if ( .link == "loglink" && (any(mupo < .Machine$double.eps))) {
       tmp600 <- mupo
       tmp600[tmp600 < .Machine$double.eps] <- .Machine$double.eps
       c(w) * tmp600
@@ -1370,9 +1384,10 @@ rinv.gaussian <- function(n, mu, lambda) {
 
 
 
+if (FALSE)
  quasibinomialff <-
   function(
-           link = "logit",
+           link = "logitlink",
            multiple.responses = FALSE, onedpar = !multiple.responses,
            parallel = FALSE, zero = NULL) {
 
@@ -1405,8 +1420,8 @@ rinv.gaussian <- function(n, mu, lambda) {
 
 
 
-
- quasipoissonff <- function(link = "loge", onedpar = FALSE,
+if (FALSE)
+ quasipoissonff <- function(link = "loglink", onedpar = FALSE,
                             parallel = FALSE, zero = NULL) {
 
   link <- as.list(substitute(link))
@@ -1437,8 +1452,8 @@ rinv.gaussian <- function(n, mu, lambda) {
 
 
  double.exppoisson <-
-  function(lmean = "loge",
-           ldispersion = "logit",
+  function(lmean = "loglink",
+           ldispersion = "logitlink",
            idispersion = 0.8,
            zero = NULL) {
 
@@ -1583,7 +1598,7 @@ rinv.gaussian <- function(n, mu, lambda) {
 
 
  double.expbinomial <-
-  function(lmean = "logit", ldispersion = "logit",
+  function(lmean = "logitlink", ldispersion = "logitlink",
            idispersion = 0.25, zero = "dispersion") {
 
   lmean <- as.list(substitute(lmean))
@@ -1771,7 +1786,7 @@ rinv.gaussian <- function(n, mu, lambda) {
 
 
 
- augbinomial <- function(link = "logit", multiple.responses = FALSE,
+ augbinomial <- function(link = "logitlink", multiple.responses = FALSE,
                          parallel = TRUE) {
 
   if (!is.logical(parallel) ||
@@ -1957,7 +1972,7 @@ rinv.gaussian <- function(n, mu, lambda) {
 
     Konst1 <- 1  # Works with this
     deriv1 <- Konst1 * w *
-      if ( .link == "logit") {
+      if ( .link == "logitlink") {
           y * (1 - mu)
       } else  {
           stop("this is not programmed in yet")
@@ -1965,7 +1980,7 @@ rinv.gaussian <- function(n, mu, lambda) {
           (y / mu - 1.0) / (1.0 - mu)
       }
     deriv2 = Konst1 * w *
-      if ( .link == "logit") {
+      if ( .link == "logitlink") {
          -(1 - y) * mu
       } else  {
           stop("this is not programmed in yet")
@@ -1980,7 +1995,7 @@ rinv.gaussian <- function(n, mu, lambda) {
   weight = eval(substitute(expression({
     tmp100 <- mu * (1.0 - mu)
 
-    tmp200 <- if ( .link == "logit") {
+    tmp200 <- if ( .link == "logitlink") {
       cbind(w * tmp100)
     } else {
       cbind(w * dtheta.deta(mu, link = .link , earg = .earg )^2 / tmp100)
